==> sync_dl-0.1.4-py3-none-any.whl: sync_dl/config.py <==
import configparser
import os
from re import compile
from ntpath import dirname
from shutil import copyfile

'''
contains all global variables, also parses config into global variables
'''



def createDefaultConfig(parser):
    defaultConfig = {
        'metaDataName' : '.metaData',
        'manualAddId' : '-manualAddition',
        'testPlPath' : 'tests/testPlaylists',
        'tmpDownloadPath' : 'tmp',
        'musicDir' : '',
    }

    parser['CONFIG'] = defaultConfig
    with open(f'{modulePath}/config.ini','w+') as f:
        parser.write(f)
    
def writeToConfig(key,value):
    parser.set('CONFIG',key,value)
    with open(f'{modulePath}/config.ini', 'w') as configfile:
        parser.write(configfile)

modulePath = dirname(__file__)

#loading config
parser = configparser.ConfigParser(allow_no_value=True)
parser.optionxform = str 

if not os.path.exists(f'{modulePath}/config.ini'):
    createDefaultConfig(parser)
    

else:
    parser.read(f'{modulePath}/config.ini')


section = parser['CONFIG']

# global config variables
filePrependRE = compile(r'\d+_')

metaDataName = section['metaDataName']

manualAddId =section['manualAddId']

testPlPath = f"{modulePath}/{section['testPlPath']}" 

tmpDownloadPath = f"{modulePath}/{section['tmpDownloadPath']}"

musicDir = section['musicDir']

# logger
import logging
logger = logging.getLogger('sync_dl')


# youtube-dl params, used in downloadID
params={"quiet": True, "noplaylist": True,
    'format': 'bestaudio', 
    'postprocessors': [
        {'key': 'FFmpegExtractAudio'},
        #{'key': 'EmbedThumbnail'},
        {'key': 'FFmpegMetadata'}
        ],
}

==> sync_dl-0.1.9-py3-none-any.whl: sync_dl/config.py <==
import configparser
import os
from re import compile
from ntpath import dirname
from shutil import copyfile

'''
contains all global variables, also parses config into global variables
'''



def createDefaultConfig(parser):
    defaultConfig = {
        'metaDataName' : '.metaData',
        'manualAddId' : '-manualAddition',
        'testPlPath' : 'tests/testPlaylists',
        'tmpDownloadPath' : 'tmp',
        'musicDir' : '',
    }

    parser['CONFIG'] = defaultConfig
    with open(f'{modulePath}/config.ini','w+') as f:
        parser.write(f)
    
def writeToConfig(key,value):
    parser.set('CONFIG',key,value)
    with open(f'{modulePath}/config.ini', 'w') as configfile:
        parser.write(configfile)

modulePath = dirname(__file__)

#loading config
parser = configparser.ConfigParser(allow_no_value=True)
parser.optionxform = str 

if not os.path.exists(f'{modulePath}/config.ini'):
    createDefaultConfig(parser)
    

else:
    parser.read(f'{modulePath}/config.ini')


section = parser['CONFIG']

# global config variables
filePrependRE = compile(r'\d+_')

metaDataName = section['metaDataName']

manualAddId =section['manualAddId']

testPlPath = f"{modulePath}/{section['testPlPath']}" 

tmpDownloadPath = f"{modulePath}/{section['tmpDownloadPath']}"

musicDir = section['musicDir']

# logger
import logging
logger = logging.getLogger('sync_dl')


# youtube-dl params, used in downloadToTmp
params={"quiet": True, "noplaylist": True,
    'format': 'bestaudio', 
    'postprocessors': [
        {'key': 'FFmpegExtractAudio'},
        #{'key': 'EmbedThumbnail'},
        {'key': 'FFmpegMetadata'}
        ],
}
